@@ -1,9 +1,10 @@
 from subprocess import run
 
+from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.prompt.sections.utils import Version
 
 
-class Dotnet(Version):
+class Dotnet(Version, Base):
     def __init__(self):
         super(Dotnet, self).__init__()
         self.files = ("project.json", "global.json", "paket.dependencies")
@@ -14,16 +15,7 @@ class Dotnet(Version):
     ) -> str:
         return super().get(config, reg_version, key=key, ext=ext, space_elem=space_elem)
 
-    def set_version(self, key="dotnet", action=None) -> bool:
-
-        version = run(
-            "dotnet --version 2>/dev/null",
-            capture_output=True,
-            shell=True,
-            text=True,
-        ).stdout
-
-        if not version.replace("\n", ""):
-            return False
-        version_format = version.replace("\n", "")
-        return super().set(version_format, key, action)
+    def set_version(self, exec_="dotnet", key="dotnet", action=None) -> bool:
+        command = run("dotnet --version", capture_output=True, shell=True, text=True)
+        version = command.stdout.replace("\n", "")
+        return super().set(command, version, exec_, key, action)
